<?php
/**
 * Pàgina principal
 *
 * Pagina principal d'on s'herenten les principals característiques de navegació per l'entorn de la CA
 * Aquí es defineixen les capçaleres, comportament dels butons i les icones, també hi ha implemetades
 * funcions de neteja deles diferents entrades dels formularis que es van donant dins l'aplicatiu
 * @author Eugeni Queralt
 * @package tfcUOC
 *
*/
class Page
{
  /**
   * Característiques de l'entorn
   *
   * Aquesta variable serà el contingut que es mostrarà en la pàgina que visualitzem en cada moment
   * El contingut podran ser misstages, formularis etc. En la majoria dels casos es genera dins de cada script
   * concret.
   *
   *
   */
  public $content;
  /**
   * @var string titol de la pàgina que es visualitza
   */
  public $title = 'TFC Safe Key CA Ltd';
  /**
   *
   * @var string Es mostra a la pàgina d'inici
   */
  public $keywords = 'Treball de fi de carrera, autoritat de certificació amb serveis en línia';
  /**
   *
   * Array de botons que es mostren amb un nom que referencia una adreça ($url) que s'utilitza per navegar
   * Dins l'
   */
  public $buttons = array
  							( 
			'Inici'     	  =>  '/tfc/principal.php',
                        'Contacte'  	  =>  '/tfc/contacte.php',
                        'Serveis públics'   	  =>  '/tfc/serveis.php',
                        'Serveis amb certificat'   =>  '/tfc/ambcert.php',
                        'Administrador'   =>  '/tfc/admin.php',
                        'Ajuda' 	  =>  '/tfc/ajuda.php'
                     );

  // Operacions de la classe
  /**
   * Mètode accessor de classe
   * @param string $name Passem el nom de l'objecte
   * @param string $value Passem el nom que volem per l'ojecte
   */
  public function __set($name, $value)
  {
    $this->$name = $value;
  }


  /**
   * Neteja entrades
   *
   * Funció que elimina possibles entrades malicioses en els formularis.
   * Les entrades que s'avaluen aquí seràn cadenes de text.
   * Es respecta també la codificació de caràcters UTF-8, es permeten accents.
   * @param string $entrada cadena de caracters succeptible de ser netejada de caracters especials
   * @return string cadena transformada
   *
   */
  public function Neteja($entrada)
  {
      $sortida = htmlentities(strip_tags(trim($entrada)), ENT_QUOTES, 'UTF-8');
      return $sortida;
  }
  /**
   * Validació email
   *
   * Funció que valida el correu electrònic introduït per l'usuari.
   * Retorna vertader si el mail és correcte, fals en un altre cas
   * @param string correu electrònic introduït
   * @return boolean Cert si el correu presenta un format acceptable
   *
   */
  public function ValidaMail($pMail)
  {
    if (ereg("^[_a-zA-Z0-9-]+(\.[_a-zA-Z0-9-]+)*@+([_a-zA-Z0-9-]+\.)*[a-zA-Z0-9-]{2,200}\.[a-zA-Z]{2,6}$", $pMail ) ) {
       return true;
    } else {
       return false;
    }
  }
  /**
   * Extracció de cadenes
   *
   * Extreu cadenes delimitades dins d'una de més gran
   * @param string $cadena Cadena de text d'on volem extreure un subcadena delimitada entre 2 subcadenes internes
   * Utils en el moment d'obtenir informació dels certificats i peticions a la CA
   * @param string $str1 Delimitador 1
   * @param string $str2 Delimitador 2
   * @return string Cadena entre $srt1 i $str2
   */

  public function treure($cadena,$str1,$str2){
            $cadena .= "|";
            $ext = explode("$str1",$cadena,2);
            $ext = explode("$str2",$ext[1]);
            $ext= $ext[0];

            return $ext;
       }

  /**
    * Codi vs. Noms dels països
    *
    * Noms en anglès del país i codi en format ISO 3166
    *
    * @param string Entrada del codi corresponent a un país en format ISO 3166 
   *  @return string Nom del país es mjúscules
   * 
  */
  public function Countries($codiPais)
  {
	$countries = array(
		"AF" => "AFGHANISTAN",
		"AX" => "ALAND ISLANDS",
		"AL" => "ALBANIA",
		"DZ" => "ALGERIA",
		"AS" => "AMERICAN SAMOA",
		"AD" => "ANDORRA",
		"AO" => "ANGOLA",
		"AI" => "ANGUILLA",
		"AQ" => "ANTARCTICA",
		"AG" => "ANTIGUA AND BARBUDA",
		"AR" => "ARGENTINA",
		"AM" => "ARMENIA",
		"AW" => "ARUBA",
		"AU" => "AUSTRALIA",
		"AT" => "AUSTRIA",
		"AZ" => "AZERBAIJAN",
		"BS" => "BAHAMAS",
		"BH" => "BAHRAIN",
		"BD" => "BANGLADESH",
		"BB" => "BARBADOS",
		"BY" => "BELARUS",
		"BE" => "BELGIUM",
		"BZ" => "BELIZE",
		"BJ" => "BENIN",
		"BM" => "BERMUDA",
		"BT" => "BHUTAN",
		"BO" => "BOLIVIA, PLURINATIONAL STATE OF",
		"BA" => "BOSNIA AND HERZEGOVINA",
		"BW" => "BOTSWANA",
		"BV" => "BOUVET ISLAND",
		"BR" => "BRAZIL",
		"IO" => "BRITISH INDIAN OCEAN TERRITORY",
		"BN" => "BRUNEI DARUSSALAM",
		"BG" => "BULGARIA",
		"BF" => "BURKINA FASO",
		"BI" => "BURUNDI",
		"KH" => "CAMBODIA",
		"CM" => "CAMEROON",
		"CA" => "CANADA",
		"CV" => "CAPE VERDE",
		"KY" => "CAYMAN ISLANDS",
		"CF" => "CENTRAL AFRICAN REPUBLIC",
		"TD" => "CHAD",
		"CL" => "CHILE",
		"CN" => "CHINA",
		"CX" => "CHRISTMAS ISLAND",
		"CC" => "COCOS (KEELING) ISLANDS",
		"CO" => "COLOMBIA",
		"KM" => "COMOROS",
		"CG" => "CONGO",
		"CD" => "CONGO, THE DEMOCRATIC REPUBLIC OF THE",
		"CK" => "COOK ISLANDS",
		"CR" => "COSTA RICA",
		"CI" => "COTE D'IVOIRE",
		"HR" => "CROATIA",
		"CU" => "CUBA",
		"CY" => "CYPRUS",
		"CZ" => "CZECH REPUBLIC",
		"DK" => "DENMARK",
		"DJ" => "DJIBOUTI",
		"DM" => "DOMINICA",
		"DO" => "DOMINICAN REPUBLIC",
		"EC" => "ECUADOR",
		"EG" => "EGYPT",
		"SV" => "EL SALVADOR",
		"GQ" => "EQUATORIAL GUINEA",
		"ER" => "ERITREA",
		"EE" => "ESTONIA",
		"ET" => "ETHIOPIA",
		"FK" => "FALKLAND ISLANDS (MALVINAS)",
		"FO" => "FAROE ISLANDS",
		"FJ" => "FIJI",
		"FI" => "FINLAND",
		"FR" => "FRANCE",
		"GF" => "FRENCH GUIANA",
		"PF" => "FRENCH POLYNESIA",
		"TF" => "FRENCH SOUTHERN TERRITORIES",
		"GA" => "GABON",
		"GM" => "GAMBIA",
		"GE" => "GEORGIA",
		"DE" => "GERMANY",
		"GH" => "GHANA",
		"GI" => "GIBRALTAR",
		"GR" => "GREECE",
		"GL" => "GREENLAND",
		"GD" => "GRENADA",
		"GP" => "GUADELOUPE",
		"GU" => "GUAM",
		"GT" => "GUATEMALA",
		"GG" => "GUERNSEY",
		"GN" => "GUINEA",
		"GW" => "GUINEA-BISSAU",
		"GY" => "GUYANA",
		"HT" => "HAITI",
		"HM" => "HEARD ISLAND AND MCDONALD ISLANDS",
		"VA" => "HOLY SEE (VATICAN CITY STATE)",
		"HN" => "HONDURAS",
		"HK" => "HONG KONG",
		"HU" => "HUNGARY",
		"IS" => "ICELAND",
		"IN" => "INDIA",
		"ID" => "INDONESIA",
		"IR" => "IRAN, ISLAMIC REPUBLIC OF",
		"IQ" => "IRAQ",
		"IE" => "IRELAND",
		"IM" => "ISLE OF MAN",
		"IL" => "ISRAEL",
		"IT" => "ITALY",
		"JM" => "JAMAICA",
		"JP" => "JAPAN",
		"JE" => "JERSEY",
		"JO" => "JORDAN",
		"KZ" => "KAZAKHSTAN",
		"KE" => "KENYA",
		"KI" => "KIRIBATI",
		"KP" => "KOREA, DEMOCRATIC PEOPLE'S REPUBLIC OF",
		"KR" => "KOREA, REPUBLIC OF",
		"KW" => "KUWAIT",
		"KG" => "KYRGYZSTAN",
		"LA" => "LAO PEOPLE'S DEMOCRATIC REPUBLIC",
		"LV" => "LATVIA",
		"LB" => "LEBANON",
		"LS" => "LESOTHO",
		"LR" => "LIBERIA",
		"LY" => "LIBYAN ARAB JAMAHIRIYA",
		"LI" => "LIECHTENSTEIN",
		"LT" => "LITHUANIA",
		"LU" => "LUXEMBOURG",
		"MO" => "MACAO",
		"MK" => "MACEDONIA, THE FORMER YUGOSLAV REPUBLIC OF",
		"MG" => "MADAGASCAR",
		"MW" => "MALAWI",
		"MY" => "MALAYSIA",
		"MV" => "MALDIVES",
		"ML" => "MALI",
		"MT" => "MALTA",
		"MH" => "MARSHALL ISLANDS",
		"MQ" => "MARTINIQUE",
		"MR" => "MAURITANIA",
		"MU" => "MAURITIUS",
		"YT" => "MAYOTTE",
		"MX" => "MEXICO",
		"FM" => "MICRONESIA, FEDERATED STATES OF",
		"MD" => "MOLDOVA, REPUBLIC OF",
		"MC" => "MONACO",
		"MN" => "MONGOLIA",
		"ME" => "MONTENEGRO",
		"MS" => "MONTSERRAT",
		"MA" => "MOROCCO",
		"MZ" => "MOZAMBIQUE",
		"MM" => "MYANMAR",
		"NA" => "NAMIBIA",
		"NR" => "NAURU",
		"NP" => "NEPAL",
		"NL" => "NETHERLANDS",
		"AN" => "NETHERLANDS ANTILLES",
		"NC" => "NEW CALEDONIA",
		"NZ" => "NEW ZEALAND",
		"NI" => "NICARAGUA",
		"NE" => "NIGER",
		"NG" => "NIGERIA",
		"NU" => "NIUE",
		"NF" => "NORFOLK ISLAND",
		"MP" => "NORTHERN MARIANA ISLANDS",
		"NO" => "NORWAY",
		"OM" => "OMAN",
		"PK" => "PAKISTAN",
		"PW" => "PALAU",
		"PS" => "PALESTINIAN TERRITORY, OCCUPIED",
		"PA" => "PANAMA",
		"PG" => "PAPUA NEW GUINEA",
		"PY" => "PARAGUAY",
		"PE" => "PERU",
		"PH" => "PHILIPPINES",
		"PN" => "PITCAIRN",
		"PL" => "POLAND",
		"PT" => "PORTUGAL",
		"PR" => "PUERTO RICO",
		"QA" => "QATAR",
		"RE" => "REUNION",
		"RO" => "ROMANIA",
		"RU" => "RUSSIAN FEDERATION",
		"RW" => "RWANDA",
		"BL" => "SAINT BARTHELEMY",
		"SH" => "SAINT HELENA, ASCENSION AND TRISTAN DA CUNHA",
		"KN" => "SAINT KITTS AND NEVIS",
		"LC" => "SAINT LUCIA",
		"MF" => "SAINT MARTIN",
		"PM" => "SAINT PIERRE AND MIQUELON",
		"VC" => "SAINT VINCENT AND THE GRENADINES",
		"WS" => "SAMOA",
		"SM" => "SAN MARINO",
		"ST" => "SAO TOME AND PRINCIPE",
		"SA" => "SAUDI ARABIA",
		"SN" => "SENEGAL",
		"RS" => "SERBIA",
		"SC" => "SEYCHELLES",
		"SL" => "SIERRA LEONE",
		"SG" => "SINGAPORE",
		"SK" => "SLOVAKIA",
		"SI" => "SLOVENIA",
		"SB" => "SOLOMON ISLANDS",
		"SO" => "SOMALIA",
		"ZA" => "SOUTH AFRICA",
		"GS" => "SOUTH GEORGIA AND THE SOUTH SANDWICH ISLANDS",
		"ES" => "SPAIN",
		"LK" => "SRI LANKA",
		"SD" => "SUDAN",
		"SR" => "SURINAME",
		"SJ" => "SVALBARD AND JAN MAYEN",
		"SZ" => "SWAZILAND",
		"SE" => "SWEDEN",
		"CH" => "SWITZERLAND",
		"SY" => "SYRIAN ARAB REPUBLIC",
		"TW" => "TAIWAN, PROVINCE OF CHINA",
		"TJ" => "TAJIKISTAN",
		"TZ" => "TANZANIA, UNITED REPUBLIC OF",
		"TH" => "THAILAND",
		"TL" => "TIMOR-LESTE",
		"TG" => "TOGO",
		"TK" => "TOKELAU",
		"TO" => "TONGA",
		"TT" => "TRINIDAD AND TOBAGO",
		"TN" => "TUNISIA",
		"TR" => "TURKEY",
		"TM" => "TURKMENISTAN",
		"TC" => "TURKS AND CAICOS ISLANDS",
		"TV" => "TUVALU",
		"UG" => "UGANDA",
		"UA" => "UKRAINE",
		"AE" => "UNITED ARAB EMIRATES",
		"GB" => "UNITED KINGDOM",
		"US" => "UNITED STATES",
		"UM" => "UNITED STATES MINOR OUTLYING ISLANDS",
		"UY" => "URUGUAY",
		"UZ" => "UZBEKISTAN",
		"VU" => "VANUATU",
		"VE" => "VENEZUELA, BOLIVARIAN REPUBLIC OF",
		"VN" => "VIET NAM",
		"VG" => "VIRGIN ISLANDS, BRITISH",
		"VI" => "VIRGIN ISLANDS, U.S.",
		"WF" => "WALLIS AND FUTUNA",
		"EH" => "WESTERN SAHARA",
		"YE" => "YEMEN",
		"ZM" => "ZAMBIA",
		"ZW" => "ZIMBABWE"
	);
	return $countries[$codiPais];
}
    /**
     * Mostra elements de la pàgina
     *
     * Funció que configura (te un petit fulls d'estils incorporat) i mostra
     * tots els elements de la pàgina que es visualitzi
     * capçaleres, contingut, peus de pàgina, títols botons per navegar, icones, jocs de caràcters...
     */
      public function Display()
          {
           // echo "<html>\n<head>\n";
            $this -> DisplayCapcalera();
            $this -> DisplayTitle();
            $this -> DisplayKeywords();
            $this -> DisplayStyles();
            echo "</head>\n<body>\n";
            $this -> DisplayHeader();
            $this -> DisplayMenu($this->buttons);
            echo $this->content;
            $this -> DisplayFooter();
            echo "</body>\n</html>\n";
          }
	/**
         * Capçaleres
         *
         * Mostra la capçalera pel joc de caràcters i la llengua
         *
         *
         */
	function DisplayCapcalera(){
	?>
		<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">  
		<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ca" lang="ca">
		<head>  
		<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
	<?
	} 
  /**
   * Mostra el títol
   *
   */
  public function DisplayTitle()
  {
    echo '<title> '.$this->title.' </title>';
  }
  /**
   * Mostra la llegenda
   *
   */
  public function DisplayKeywords()
  {
    echo "<meta name=\"keywords\" content=\"$this->keywords\" />";
  }

  /**
   * Full d'estils de l'aplicació
   *
   */
  public function DisplayStyles()
  { 
?>   
  <style>
    h1 {color:white; font-size:24pt; text-align:left; 
        font-family:arial,sans-serif}
    .menu {color:white; font-size:12pt; text-align:left; 
           font-family:arial,sans-serif; font-weight:bold}
    td {background:green; text-align:left; -moz-border-radius: 5px 5px 5px 5px}
    p {color:black; font-size:12pt; text-align:justify; 
       font-family:arial,sans-serif}
    p.foot {color:white; font-size:9pt; text-align:center; 
            font-family:arial,sans-serif; font-weight:bold}
    a:link,a:visited,a:active {color:white}
  </style>
<?php
  }

  /**
   * Mostra taula per la capçalera
   *
   */
  public function DisplayHeader()
  { 
?>   
	<table width="100%" cellpadding ="12" cellspacing ="0" border ="0">
	<tr bgcolor ="white">
	<td>
		<img src = "imatges/logo.gif" />
	    <h1> TFC Safe Key CA</h1>
	</td>  
	</tr>
  </table>
<?php
  }

  /**
   * Mostra el menú dels botons
   *
   */
  public function DisplayMenu($buttons)
  {
    echo "<table width='100%' bgcolor='white' cellpadding='4' 
                cellspacing='4'\n";
    echo "  <tr>\n";

    /**
     * @var int Calcula la mida dels botons (tota l'amplada)
     *
     */
    $width = 100/count($buttons);

    while (list($name, $url) = each($buttons))
    {
        $this -> DisplayButton($width, $name, $url, !$this->IsURLCurrentPage($url));
    }
    echo "  </tr>\n";
    echo "</table>\n";
  }

  /**
   * Retorna cert si som a la pàgina actual.En concret comprova si $_SERVER['PHP_SELF'] es igual al array
   * del boto associat a la variable $url (que conté l'enllaç a la pagina del botó)
   * @param string $url enllaç a la pàgina on es vol anar
   * @return boolean cert si la pàgina actual és la que referencia el botó
   */
  public function IsURLCurrentPage($url)
  {
    if($url == $_SERVER['PHP_SELF'])
    {
      return true;
    }
    else
    {
      return false;
    }
  }

  /**
   * Mostra un botó de navegació
   *
   * Mostra un botó amb la mida adequada a l'amplada total de la pàgina repartida entre tots els altres botons
   * Es passa també l'etiqueta del botó, l'enllaç on ens porta i la indicació de si ens trobem
   * a la pàgina actual o no. En funció de si la pàgina està activa (es l'actual)o nó s'insereix una icona
   * dreta o apaisada, per pura raó estètica.
   * 
   * @param int $width Amplada del botó
   * @param string $name Etiqueta del botó que es mostra a la pantalla
   * @param boolean $active Cert si el botó referencia la pàgina activa
   */
  public function DisplayButton($width, $name, $url, $active = true)
  {
    if ($active)
    {
      echo "<td width ='$width%'>
            <a href ='$url'>
            <img src ='/tfc/imatges/dret-logo.gif' alt ='$name' border ='0' /></a>
            <a href ='$url'><span class='menu'>$name</span></a></td>";
    }  
    else
    {
      echo "<td width ='$width%'>
            <img src ='/tfc/imatges/costat-logo.gif'>
            <span class='menu'>$name</span></td>";
    }  
  }
  /**
   * Mostra el peu de pàgina i la llicència cc
   *
   */
  public function DisplayFooter()
  {
?>
    <table width = "100%" bgcolor ="white" cellpadding ="12" border ="0">
    <tr>
      <td>
        <p class="foot"> TFC Safe Key CA Ltd.</p>
        <p class="foot"><a rel="license" href="http://creativecommons.org/licenses/by/3.0/"><img alt="Creative Commons License" 
												style="border-width:0" 
												src="http://i.creativecommons.org/l/by/3.0/80x15.png" /></a><br />This work is licensed under a <a rel="license" 
												href="http://creativecommons.org/licenses/by/3.0/">Creative Commons Attribution 3.0 Unported License</a>.</p>
      </td>
    </tr>
    </table>
<?php
  }
}
?>
